;; Generated package description from yasnippet-classic-snippets.el  -*- no-byte-compile: t -*-
(define-package "yasnippet-classic-snippets" "1.0.2" "\"Classic\" yasnippet snippets" '((yasnippet "0.9.1")) :commit "43ff0337f5ec504f2a496f2f035a5087cd8e2074" :url "https://elpa.gnu.org/packages/yasnippet-classic-snippets.html" :maintainer '("Noam Postavsky" . "npostavs@gmail.com") :keywords '("snippets"))
